@@ -136,21 +136,27 @@ class tokenize:
         return self
 
 
-def get_tokenizer(tag,chunkers=None,filters=None):
+def get_tokenizer(tag=None,chunkers=None,filters=None):
     """Locate an appropriate tokenizer by language tag.
 
-    This requires importing the function 'tokenize' from an
-    appropriate module.  Modules tried are named after the
-    language tag, tried in the following order:
+    This requires importing the function 'tokenize' from an appropriate
+    module.  Modules tried are named after the language tag, tried in the
+    following order:
         * the entire tag (e.g. "en_AU.py")
         * the base country code of the tag (e.g. "en.py")
 
+    If the language tag is None, a default tokenizer (actually the English
+    one) is returned.  It's unicode aware and should work OK for most
+    latin-derived languages.
+
     If a suitable function cannot be found, raises TokenizerNotFoundError.
     
     If given and not None, 'chunkers' and 'filters' must be lists of chunker
     classes and filter classes resectively.  These will be applied to the
     tokenizer during creation.
     """
+    if tag is None:
+        tag = "en"
     # "filters" used to be the second argument.  Try to catch cases
     # where it is given positionally and issue a DeprecationWarning.
     if chunkers is not None and filters is None:
@@ -468,9 +474,17 @@ class HTMLChunker(Chunker):
                 break
             #  Skip to the end of the current tag, if any.
             if text[offset] == "<":
-                while text[offset] != ">":
-                    offset += 1
-                offset += 1
+                maybeTag = offset
+                if self._is_tag(text,offset):
+                    while text[offset] != ">":
+                        offset += 1
+                        if offset == len(text):
+                            offset = maybeTag+1
+                            break
+                    else:
+                        offset += 1
+                else:
+                    offset = maybeTag+1
             sPos = offset
             #  Find the start of the next tag.
             while offset < len(text) and text[offset] != "<":
@@ -482,6 +496,14 @@ class HTMLChunker(Chunker):
                 return (text[sPos:offset],sPos)
         raise StopIteration()
 
+    def _is_tag(self,text,offset):
+        if offset+1 < len(text):
+            if text[offset+1].isalpha():
+                return True
+            if text[offset+1] == "/":
+                return True
+        return False
+
 
 #TODO: LaTeXChunker
 
